@@ -1,10 +1,10 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.18.0';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.18.1';
 use strict;
 use warnings;
 use autodie;
 
-use Carp ();
+use Carp;
 
 use MooX 'late';
 
@@ -115,7 +115,12 @@ sub _write_scene_main
     }
 
     my $title = $scene->lookup_attr("title");
+    my $lang  = $scene->lookup_attr("lang");
     my @t     = ( defined($title) ? ( title => $title ) : () );
+    if ( defined($lang) )
+    {
+        push @t, ( [ $self->_get_xml_xml_ns, 'lang' ] => $lang );
+    }
 
     $self->_output_tag_with_childs(
         {
@@ -163,7 +168,7 @@ __END__
 
 =head1 VERSION
 
-version 0.18.0
+version 0.18.1
 
 =head1 NAME
 
